import ast

from padl.dumptools import var2mod


class TestFindGlobals:
    def test_find_same_name(self):
        statement = 'a = run(a)'
        tree = ast.parse(statement)
        res = var2mod.find_globals(tree)
        assert res == {('a', 1), ('run', 0)}

    def test_find_in_assignment(self):
        statement = 'a = run'
        tree = ast.parse(statement)
        res = var2mod.find_globals(tree)
        assert res == {('run', 0)}



from padl import transform


@transform
def function(x):
    return x


@transform
class Class:
    def __init__(self, x):
        self.x = x

    def __call__(self, y):
        return self.x + y


var = 100
obj = Class(var)

compound = obj >> obj + function >> function / function
